/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6-DataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qitemmodelsurfacedataproxy.sip"
#include <qitemmodelsurfacedataproxy.h>
#line 29 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"

#line 121 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 33 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"
#line 24 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 42 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 45 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"
#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qsurface3dseries.sip"
#include <qsurface3dseries.h>
#line 48 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"
#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qsurfacedataitem.sip"
#include <qsurfacedataitem.h>
#line 51 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpoint.sip"
#include <qpoint.h>
#line 54 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"
#line 27 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qlist.sip"
#include <qlist.h>
#line 57 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 60 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"
#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 63 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 68 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 71 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 74 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"
#line 277 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 77 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"
#line 254 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 80 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 83 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 86 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 89 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"
#line 135 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 92 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 97 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 100 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 103 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"
#line 25 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qflags.sip"
#include <qglobal.h>
#line 106 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 109 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQItemModelSurfaceDataProxy.cpp"


class sipQItemModelSurfaceDataProxy : public ::QItemModelSurfaceDataProxy
{
public:
    sipQItemModelSurfaceDataProxy(::QAbstractItemModel*, ::QObject*);
    sipQItemModelSurfaceDataProxy(::QAbstractItemModel*, const ::QString&, ::QObject*);
    sipQItemModelSurfaceDataProxy(::QAbstractItemModel*, const ::QString&, const ::QString&, const ::QString&, ::QObject*);
    sipQItemModelSurfaceDataProxy(::QAbstractItemModel*, const ::QString&, const ::QString&, const ::QString&, const ::QStringList&, const ::QStringList&, ::QObject*);
    sipQItemModelSurfaceDataProxy(::QAbstractItemModel*, const ::QString&, const ::QString&, const ::QString&, const ::QString&, const ::QString&, ::QObject*);
    sipQItemModelSurfaceDataProxy(::QAbstractItemModel*, const ::QString&, const ::QString&, const ::QString&, const ::QString&, const ::QString&, const ::QStringList&, const ::QStringList&, ::QObject*);
    sipQItemModelSurfaceDataProxy(::QObject*);
    virtual ~sipQItemModelSurfaceDataProxy();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQItemModelSurfaceDataProxy(const sipQItemModelSurfaceDataProxy &);
    sipQItemModelSurfaceDataProxy &operator = (const sipQItemModelSurfaceDataProxy &);

    char sipPyMethods[7];
};

sipQItemModelSurfaceDataProxy::sipQItemModelSurfaceDataProxy(::QAbstractItemModel*a0, ::QObject*a1): ::QItemModelSurfaceDataProxy(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQItemModelSurfaceDataProxy::sipQItemModelSurfaceDataProxy(::QAbstractItemModel*a0, const ::QString& a1, ::QObject*a2): ::QItemModelSurfaceDataProxy(a0, a1, a2), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQItemModelSurfaceDataProxy::sipQItemModelSurfaceDataProxy(::QAbstractItemModel*a0, const ::QString& a1, const ::QString& a2, const ::QString& a3, ::QObject*a4): ::QItemModelSurfaceDataProxy(a0, a1, a2, a3, a4), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQItemModelSurfaceDataProxy::sipQItemModelSurfaceDataProxy(::QAbstractItemModel*a0, const ::QString& a1, const ::QString& a2, const ::QString& a3, const ::QStringList& a4, const ::QStringList& a5, ::QObject*a6): ::QItemModelSurfaceDataProxy(a0, a1, a2, a3, a4, a5, a6), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQItemModelSurfaceDataProxy::sipQItemModelSurfaceDataProxy(::QAbstractItemModel*a0, const ::QString& a1, const ::QString& a2, const ::QString& a3, const ::QString& a4, const ::QString& a5, ::QObject*a6): ::QItemModelSurfaceDataProxy(a0, a1, a2, a3, a4, a5, a6), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQItemModelSurfaceDataProxy::sipQItemModelSurfaceDataProxy(::QAbstractItemModel*a0, const ::QString& a1, const ::QString& a2, const ::QString& a3, const ::QString& a4, const ::QString& a5, const ::QStringList& a6, const ::QStringList& a7, ::QObject*a8): ::QItemModelSurfaceDataProxy(a0, a1, a2, a3, a4, a5, a6, a7, a8), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQItemModelSurfaceDataProxy::sipQItemModelSurfaceDataProxy(::QObject*a0): ::QItemModelSurfaceDataProxy(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQItemModelSurfaceDataProxy::~sipQItemModelSurfaceDataProxy()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQItemModelSurfaceDataProxy::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtDataVisualization_qt_metaobject(sipPySelf, sipType_QItemModelSurfaceDataProxy);

    return ::QItemModelSurfaceDataProxy::metaObject();
}

int sipQItemModelSurfaceDataProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QItemModelSurfaceDataProxy::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtDataVisualization_qt_metacall(sipPySelf, sipType_QItemModelSurfaceDataProxy, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQItemModelSurfaceDataProxy::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtDataVisualization_qt_metacast(sipPySelf, sipType_QItemModelSurfaceDataProxy, _clname, &sipCpp) ? sipCpp : ::QItemModelSurfaceDataProxy::qt_metacast(_clname));
}

bool sipQItemModelSurfaceDataProxy::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QItemModelSurfaceDataProxy::event(a0);

    extern bool sipVH_QtDataVisualization_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtDataVisualization_18(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQItemModelSurfaceDataProxy::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QItemModelSurfaceDataProxy::eventFilter(a0, a1);

    extern bool sipVH_QtDataVisualization_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtDataVisualization_19(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQItemModelSurfaceDataProxy::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QItemModelSurfaceDataProxy::timerEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQItemModelSurfaceDataProxy::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QItemModelSurfaceDataProxy::childEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtDataVisualization_21(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQItemModelSurfaceDataProxy::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QItemModelSurfaceDataProxy::customEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtDataVisualization_22(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQItemModelSurfaceDataProxy::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QItemModelSurfaceDataProxy::connectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_23(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQItemModelSurfaceDataProxy::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QItemModelSurfaceDataProxy::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_23(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_setItemModel, "setItemModel(self, itemModel: QAbstractItemModel|None)");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_setItemModel(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_setItemModel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractItemModel* a0;
        PyObject *a0Keep;
        ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp, &a0Keep, sipType_QAbstractItemModel, &a0))
        {
            sipCpp->setItemModel(a0);

            sipKeepReference(sipSelf, 120, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_setItemModel, doc_QItemModelSurfaceDataProxy_setItemModel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_itemModel, "itemModel(self) -> QAbstractItemModel|None");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_itemModel(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_itemModel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp))
        {
            ::QAbstractItemModel*sipRes;

            sipRes = sipCpp->itemModel();

            return sipConvertFromType(sipRes, sipType_QAbstractItemModel, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_itemModel, doc_QItemModelSurfaceDataProxy_itemModel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_setRowRole, "setRowRole(self, role: str|None)");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_setRowRole(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_setRowRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setRowRole(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_setRowRole, doc_QItemModelSurfaceDataProxy_setRowRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_rowRole, "rowRole(self) -> str");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_rowRole(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_rowRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->rowRole());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_rowRole, doc_QItemModelSurfaceDataProxy_rowRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_setColumnRole, "setColumnRole(self, role: str|None)");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_setColumnRole(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_setColumnRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setColumnRole(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_setColumnRole, doc_QItemModelSurfaceDataProxy_setColumnRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_columnRole, "columnRole(self) -> str");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_columnRole(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_columnRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->columnRole());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_columnRole, doc_QItemModelSurfaceDataProxy_columnRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_setRowCategories, "setRowCategories(self, categories: Iterable[str|None])");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_setRowCategories(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_setRowCategories(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStringList* a0;
        int a0State = 0;
        ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp, sipType_QStringList, &a0, &a0State))
        {
            sipCpp->setRowCategories(*a0);
            sipReleaseType(const_cast< ::QStringList *>(a0), sipType_QStringList, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_setRowCategories, doc_QItemModelSurfaceDataProxy_setRowCategories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_rowCategories, "rowCategories(self) -> list[str]");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_rowCategories(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_rowCategories(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->rowCategories());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_rowCategories, doc_QItemModelSurfaceDataProxy_rowCategories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_setColumnCategories, "setColumnCategories(self, categories: Iterable[str|None])");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_setColumnCategories(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_setColumnCategories(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStringList* a0;
        int a0State = 0;
        ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp, sipType_QStringList, &a0, &a0State))
        {
            sipCpp->setColumnCategories(*a0);
            sipReleaseType(const_cast< ::QStringList *>(a0), sipType_QStringList, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_setColumnCategories, doc_QItemModelSurfaceDataProxy_setColumnCategories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_columnCategories, "columnCategories(self) -> list[str]");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_columnCategories(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_columnCategories(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->columnCategories());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_columnCategories, doc_QItemModelSurfaceDataProxy_columnCategories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_setUseModelCategories, "setUseModelCategories(self, enable: bool)");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_setUseModelCategories(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_setUseModelCategories(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp, &a0))
        {
            sipCpp->setUseModelCategories(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_setUseModelCategories, doc_QItemModelSurfaceDataProxy_setUseModelCategories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_useModelCategories, "useModelCategories(self) -> bool");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_useModelCategories(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_useModelCategories(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->useModelCategories();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_useModelCategories, doc_QItemModelSurfaceDataProxy_useModelCategories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_setAutoRowCategories, "setAutoRowCategories(self, enable: bool)");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_setAutoRowCategories(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_setAutoRowCategories(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp, &a0))
        {
            sipCpp->setAutoRowCategories(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_setAutoRowCategories, doc_QItemModelSurfaceDataProxy_setAutoRowCategories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_autoRowCategories, "autoRowCategories(self) -> bool");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_autoRowCategories(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_autoRowCategories(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->autoRowCategories();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_autoRowCategories, doc_QItemModelSurfaceDataProxy_autoRowCategories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_setAutoColumnCategories, "setAutoColumnCategories(self, enable: bool)");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_setAutoColumnCategories(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_setAutoColumnCategories(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp, &a0))
        {
            sipCpp->setAutoColumnCategories(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_setAutoColumnCategories, doc_QItemModelSurfaceDataProxy_setAutoColumnCategories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_autoColumnCategories, "autoColumnCategories(self) -> bool");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_autoColumnCategories(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_autoColumnCategories(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->autoColumnCategories();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_autoColumnCategories, doc_QItemModelSurfaceDataProxy_autoColumnCategories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_rowCategoryIndex, "rowCategoryIndex(self, category: str|None) -> int");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_rowCategoryIndex(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_rowCategoryIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            int sipRes;

            sipRes = sipCpp->rowCategoryIndex(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_rowCategoryIndex, doc_QItemModelSurfaceDataProxy_rowCategoryIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_columnCategoryIndex, "columnCategoryIndex(self, category: str|None) -> int");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_columnCategoryIndex(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_columnCategoryIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            int sipRes;

            sipRes = sipCpp->columnCategoryIndex(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_columnCategoryIndex, doc_QItemModelSurfaceDataProxy_columnCategoryIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_setXPosRole, "setXPosRole(self, role: str|None)");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_setXPosRole(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_setXPosRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setXPosRole(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_setXPosRole, doc_QItemModelSurfaceDataProxy_setXPosRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_xPosRole, "xPosRole(self) -> str");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_xPosRole(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_xPosRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->xPosRole());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_xPosRole, doc_QItemModelSurfaceDataProxy_xPosRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_setYPosRole, "setYPosRole(self, role: str|None)");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_setYPosRole(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_setYPosRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setYPosRole(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_setYPosRole, doc_QItemModelSurfaceDataProxy_setYPosRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_yPosRole, "yPosRole(self) -> str");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_yPosRole(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_yPosRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->yPosRole());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_yPosRole, doc_QItemModelSurfaceDataProxy_yPosRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_setZPosRole, "setZPosRole(self, role: str|None)");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_setZPosRole(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_setZPosRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setZPosRole(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_setZPosRole, doc_QItemModelSurfaceDataProxy_setZPosRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_zPosRole, "zPosRole(self) -> str");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_zPosRole(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_zPosRole(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->zPosRole());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_zPosRole, doc_QItemModelSurfaceDataProxy_zPosRole);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_remap, "remap(self, rowRole: str|None, columnRole: str|None, xPosRole: str|None, yPosRole: str|None, zPosRole: str|None, rowCategories: Iterable[str|None], columnCategories: Iterable[str|None])");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_remap(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_remap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        const ::QString* a2;
        int a2State = 0;
        const ::QString* a3;
        int a3State = 0;
        const ::QString* a4;
        int a4State = 0;
        const ::QStringList* a5;
        int a5State = 0;
        const ::QStringList* a6;
        int a6State = 0;
        ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1J1J1J1J1J1", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State, sipType_QString, &a3, &a3State, sipType_QString, &a4, &a4State, sipType_QStringList, &a5, &a5State, sipType_QStringList, &a6, &a6State))
        {
            sipCpp->remap(*a0, *a1, *a2, *a3, *a4, *a5, *a6);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);
            sipReleaseType(const_cast< ::QString *>(a3), sipType_QString, a3State);
            sipReleaseType(const_cast< ::QString *>(a4), sipType_QString, a4State);
            sipReleaseType(const_cast< ::QStringList *>(a5), sipType_QStringList, a5State);
            sipReleaseType(const_cast< ::QStringList *>(a6), sipType_QStringList, a6State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_remap, doc_QItemModelSurfaceDataProxy_remap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_setRowRolePattern, "setRowRolePattern(self, pattern: QRegularExpression)");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_setRowRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_setRowRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRegularExpression* a0;
        ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp, sipType_QRegularExpression, &a0))
        {
            sipCpp->setRowRolePattern(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_setRowRolePattern, doc_QItemModelSurfaceDataProxy_setRowRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_rowRolePattern, "rowRolePattern(self) -> QRegularExpression");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_rowRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_rowRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp))
        {
            ::QRegularExpression*sipRes;

            sipRes = new ::QRegularExpression(sipCpp->rowRolePattern());

            return sipConvertFromNewType(sipRes, sipType_QRegularExpression, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_rowRolePattern, doc_QItemModelSurfaceDataProxy_rowRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_setColumnRolePattern, "setColumnRolePattern(self, pattern: QRegularExpression)");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_setColumnRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_setColumnRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRegularExpression* a0;
        ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp, sipType_QRegularExpression, &a0))
        {
            sipCpp->setColumnRolePattern(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_setColumnRolePattern, doc_QItemModelSurfaceDataProxy_setColumnRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_columnRolePattern, "columnRolePattern(self) -> QRegularExpression");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_columnRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_columnRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp))
        {
            ::QRegularExpression*sipRes;

            sipRes = new ::QRegularExpression(sipCpp->columnRolePattern());

            return sipConvertFromNewType(sipRes, sipType_QRegularExpression, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_columnRolePattern, doc_QItemModelSurfaceDataProxy_columnRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_setXPosRolePattern, "setXPosRolePattern(self, pattern: QRegularExpression)");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_setXPosRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_setXPosRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRegularExpression* a0;
        ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp, sipType_QRegularExpression, &a0))
        {
            sipCpp->setXPosRolePattern(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_setXPosRolePattern, doc_QItemModelSurfaceDataProxy_setXPosRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_xPosRolePattern, "xPosRolePattern(self) -> QRegularExpression");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_xPosRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_xPosRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp))
        {
            ::QRegularExpression*sipRes;

            sipRes = new ::QRegularExpression(sipCpp->xPosRolePattern());

            return sipConvertFromNewType(sipRes, sipType_QRegularExpression, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_xPosRolePattern, doc_QItemModelSurfaceDataProxy_xPosRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_setYPosRolePattern, "setYPosRolePattern(self, pattern: QRegularExpression)");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_setYPosRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_setYPosRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRegularExpression* a0;
        ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp, sipType_QRegularExpression, &a0))
        {
            sipCpp->setYPosRolePattern(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_setYPosRolePattern, doc_QItemModelSurfaceDataProxy_setYPosRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_yPosRolePattern, "yPosRolePattern(self) -> QRegularExpression");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_yPosRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_yPosRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp))
        {
            ::QRegularExpression*sipRes;

            sipRes = new ::QRegularExpression(sipCpp->yPosRolePattern());

            return sipConvertFromNewType(sipRes, sipType_QRegularExpression, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_yPosRolePattern, doc_QItemModelSurfaceDataProxy_yPosRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_setZPosRolePattern, "setZPosRolePattern(self, pattern: QRegularExpression)");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_setZPosRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_setZPosRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRegularExpression* a0;
        ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp, sipType_QRegularExpression, &a0))
        {
            sipCpp->setZPosRolePattern(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_setZPosRolePattern, doc_QItemModelSurfaceDataProxy_setZPosRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_zPosRolePattern, "zPosRolePattern(self) -> QRegularExpression");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_zPosRolePattern(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_zPosRolePattern(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp))
        {
            ::QRegularExpression*sipRes;

            sipRes = new ::QRegularExpression(sipCpp->zPosRolePattern());

            return sipConvertFromNewType(sipRes, sipType_QRegularExpression, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_zPosRolePattern, doc_QItemModelSurfaceDataProxy_zPosRolePattern);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_setRowRoleReplace, "setRowRoleReplace(self, replace: str|None)");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_setRowRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_setRowRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setRowRoleReplace(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_setRowRoleReplace, doc_QItemModelSurfaceDataProxy_setRowRoleReplace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_rowRoleReplace, "rowRoleReplace(self) -> str");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_rowRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_rowRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->rowRoleReplace());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_rowRoleReplace, doc_QItemModelSurfaceDataProxy_rowRoleReplace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_setColumnRoleReplace, "setColumnRoleReplace(self, replace: str|None)");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_setColumnRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_setColumnRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setColumnRoleReplace(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_setColumnRoleReplace, doc_QItemModelSurfaceDataProxy_setColumnRoleReplace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_columnRoleReplace, "columnRoleReplace(self) -> str");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_columnRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_columnRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->columnRoleReplace());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_columnRoleReplace, doc_QItemModelSurfaceDataProxy_columnRoleReplace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_setXPosRoleReplace, "setXPosRoleReplace(self, replace: str|None)");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_setXPosRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_setXPosRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setXPosRoleReplace(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_setXPosRoleReplace, doc_QItemModelSurfaceDataProxy_setXPosRoleReplace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_xPosRoleReplace, "xPosRoleReplace(self) -> str");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_xPosRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_xPosRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->xPosRoleReplace());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_xPosRoleReplace, doc_QItemModelSurfaceDataProxy_xPosRoleReplace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_setYPosRoleReplace, "setYPosRoleReplace(self, replace: str|None)");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_setYPosRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_setYPosRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setYPosRoleReplace(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_setYPosRoleReplace, doc_QItemModelSurfaceDataProxy_setYPosRoleReplace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_yPosRoleReplace, "yPosRoleReplace(self) -> str");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_yPosRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_yPosRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->yPosRoleReplace());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_yPosRoleReplace, doc_QItemModelSurfaceDataProxy_yPosRoleReplace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_setZPosRoleReplace, "setZPosRoleReplace(self, replace: str|None)");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_setZPosRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_setZPosRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setZPosRoleReplace(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_setZPosRoleReplace, doc_QItemModelSurfaceDataProxy_setZPosRoleReplace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_zPosRoleReplace, "zPosRoleReplace(self) -> str");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_zPosRoleReplace(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_zPosRoleReplace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->zPosRoleReplace());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_zPosRoleReplace, doc_QItemModelSurfaceDataProxy_zPosRoleReplace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_setMultiMatchBehavior, "setMultiMatchBehavior(self, behavior: QItemModelSurfaceDataProxy.MultiMatchBehavior)");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_setMultiMatchBehavior(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_setMultiMatchBehavior(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QItemModelSurfaceDataProxy::MultiMatchBehavior a0;
        ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp, sipType_QItemModelSurfaceDataProxy_MultiMatchBehavior, &a0))
        {
            sipCpp->setMultiMatchBehavior(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_setMultiMatchBehavior, doc_QItemModelSurfaceDataProxy_setMultiMatchBehavior);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy_multiMatchBehavior, "multiMatchBehavior(self) -> QItemModelSurfaceDataProxy.MultiMatchBehavior");

extern "C" {static PyObject *meth_QItemModelSurfaceDataProxy_multiMatchBehavior(PyObject *, PyObject *);}
static PyObject *meth_QItemModelSurfaceDataProxy_multiMatchBehavior(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QItemModelSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QItemModelSurfaceDataProxy, &sipCpp))
        {
            ::QItemModelSurfaceDataProxy::MultiMatchBehavior sipRes;

            sipRes = sipCpp->multiMatchBehavior();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QItemModelSurfaceDataProxy_MultiMatchBehavior);
        }
    }

    sipNoMethod(sipParseErr, sipName_QItemModelSurfaceDataProxy, sipName_multiMatchBehavior, doc_QItemModelSurfaceDataProxy_multiMatchBehavior);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QItemModelSurfaceDataProxy(void *, const sipTypeDef *);}
static void *cast_QItemModelSurfaceDataProxy(void *sipCppV, const sipTypeDef *targetType)
{
    ::QItemModelSurfaceDataProxy *sipCpp = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(sipCppV);

    if (targetType == sipType_QItemModelSurfaceDataProxy)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QSurfaceDataProxy)->ctd_cast(static_cast< ::QSurfaceDataProxy *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QItemModelSurfaceDataProxy(void *, int);}
static void release_QItemModelSurfaceDataProxy(void *sipCppV, int)
{
    ::QItemModelSurfaceDataProxy *sipCpp = reinterpret_cast< ::QItemModelSurfaceDataProxy *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QItemModelSurfaceDataProxy(Py_ssize_t);}
static void *array_QItemModelSurfaceDataProxy(Py_ssize_t sipNrElem)
{
    return new ::QItemModelSurfaceDataProxy[sipNrElem];
}


extern "C" {static void array_delete_QItemModelSurfaceDataProxy(void *);}
static void array_delete_QItemModelSurfaceDataProxy(void *sipCpp)
{
    delete[] reinterpret_cast< ::QItemModelSurfaceDataProxy *>(sipCpp);
}


extern "C" {static void dealloc_QItemModelSurfaceDataProxy(sipSimpleWrapper *);}
static void dealloc_QItemModelSurfaceDataProxy(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQItemModelSurfaceDataProxy *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QItemModelSurfaceDataProxy(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QItemModelSurfaceDataProxy(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QItemModelSurfaceDataProxy(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQItemModelSurfaceDataProxy *sipCpp = SIP_NULLPTR;

    {
        ::QAbstractItemModel* a0;
        PyObject *a0Keep;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "@J8|JH", &a0Keep, sipType_QAbstractItemModel, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQItemModelSurfaceDataProxy(a0, a1);

            sipKeepReference((PyObject *)sipSelf, 120, a0Keep);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QAbstractItemModel* a0;
        PyObject *a0Keep;
        const ::QString* a1;
        int a1State = 0;
        ::QObject* a2 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "@J8J1|JH", &a0Keep, sipType_QAbstractItemModel, &a0, sipType_QString, &a1, &a1State, sipType_QObject, &a2, sipOwner))
        {
            sipCpp = new sipQItemModelSurfaceDataProxy(a0, *a1, a2);

            sipKeepReference((PyObject *)sipSelf, 120, a0Keep);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QAbstractItemModel* a0;
        PyObject *a0Keep;
        const ::QString* a1;
        int a1State = 0;
        const ::QString* a2;
        int a2State = 0;
        const ::QString* a3;
        int a3State = 0;
        ::QObject* a4 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "@J8J1J1J1|JH", &a0Keep, sipType_QAbstractItemModel, &a0, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State, sipType_QString, &a3, &a3State, sipType_QObject, &a4, sipOwner))
        {
            sipCpp = new sipQItemModelSurfaceDataProxy(a0, *a1, *a2, *a3, a4);

            sipKeepReference((PyObject *)sipSelf, 120, a0Keep);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);
            sipReleaseType(const_cast< ::QString *>(a3), sipType_QString, a3State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QAbstractItemModel* a0;
        PyObject *a0Keep;
        const ::QString* a1;
        int a1State = 0;
        const ::QString* a2;
        int a2State = 0;
        const ::QString* a3;
        int a3State = 0;
        const ::QStringList* a4;
        int a4State = 0;
        const ::QStringList* a5;
        int a5State = 0;
        ::QObject* a6 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "@J8J1J1J1J1J1|JH", &a0Keep, sipType_QAbstractItemModel, &a0, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State, sipType_QString, &a3, &a3State, sipType_QStringList, &a4, &a4State, sipType_QStringList, &a5, &a5State, sipType_QObject, &a6, sipOwner))
        {
            sipCpp = new sipQItemModelSurfaceDataProxy(a0, *a1, *a2, *a3, *a4, *a5, a6);

            sipKeepReference((PyObject *)sipSelf, 120, a0Keep);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);
            sipReleaseType(const_cast< ::QString *>(a3), sipType_QString, a3State);
            sipReleaseType(const_cast< ::QStringList *>(a4), sipType_QStringList, a4State);
            sipReleaseType(const_cast< ::QStringList *>(a5), sipType_QStringList, a5State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QAbstractItemModel* a0;
        PyObject *a0Keep;
        const ::QString* a1;
        int a1State = 0;
        const ::QString* a2;
        int a2State = 0;
        const ::QString* a3;
        int a3State = 0;
        const ::QString* a4;
        int a4State = 0;
        const ::QString* a5;
        int a5State = 0;
        ::QObject* a6 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "@J8J1J1J1J1J1|JH", &a0Keep, sipType_QAbstractItemModel, &a0, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State, sipType_QString, &a3, &a3State, sipType_QString, &a4, &a4State, sipType_QString, &a5, &a5State, sipType_QObject, &a6, sipOwner))
        {
            sipCpp = new sipQItemModelSurfaceDataProxy(a0, *a1, *a2, *a3, *a4, *a5, a6);

            sipKeepReference((PyObject *)sipSelf, 120, a0Keep);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);
            sipReleaseType(const_cast< ::QString *>(a3), sipType_QString, a3State);
            sipReleaseType(const_cast< ::QString *>(a4), sipType_QString, a4State);
            sipReleaseType(const_cast< ::QString *>(a5), sipType_QString, a5State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QAbstractItemModel* a0;
        PyObject *a0Keep;
        const ::QString* a1;
        int a1State = 0;
        const ::QString* a2;
        int a2State = 0;
        const ::QString* a3;
        int a3State = 0;
        const ::QString* a4;
        int a4State = 0;
        const ::QString* a5;
        int a5State = 0;
        const ::QStringList* a6;
        int a6State = 0;
        const ::QStringList* a7;
        int a7State = 0;
        ::QObject* a8 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "@J8J1J1J1J1J1J1J1|JH", &a0Keep, sipType_QAbstractItemModel, &a0, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State, sipType_QString, &a3, &a3State, sipType_QString, &a4, &a4State, sipType_QString, &a5, &a5State, sipType_QStringList, &a6, &a6State, sipType_QStringList, &a7, &a7State, sipType_QObject, &a8, sipOwner))
        {
            sipCpp = new sipQItemModelSurfaceDataProxy(a0, *a1, *a2, *a3, *a4, *a5, *a6, *a7, a8);

            sipKeepReference((PyObject *)sipSelf, 120, a0Keep);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);
            sipReleaseType(const_cast< ::QString *>(a3), sipType_QString, a3State);
            sipReleaseType(const_cast< ::QString *>(a4), sipType_QString, a4State);
            sipReleaseType(const_cast< ::QString *>(a5), sipType_QString, a5State);
            sipReleaseType(const_cast< ::QStringList *>(a6), sipType_QStringList, a6State);
            sipReleaseType(const_cast< ::QStringList *>(a7), sipType_QStringList, a7State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQItemModelSurfaceDataProxy(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QItemModelSurfaceDataProxy[] = {{67, 255, 1}};


static PyMethodDef methods_QItemModelSurfaceDataProxy[] = {
    {sipName_autoColumnCategories, meth_QItemModelSurfaceDataProxy_autoColumnCategories, METH_VARARGS, doc_QItemModelSurfaceDataProxy_autoColumnCategories},
    {sipName_autoRowCategories, meth_QItemModelSurfaceDataProxy_autoRowCategories, METH_VARARGS, doc_QItemModelSurfaceDataProxy_autoRowCategories},
    {sipName_columnCategories, meth_QItemModelSurfaceDataProxy_columnCategories, METH_VARARGS, doc_QItemModelSurfaceDataProxy_columnCategories},
    {sipName_columnCategoryIndex, meth_QItemModelSurfaceDataProxy_columnCategoryIndex, METH_VARARGS, doc_QItemModelSurfaceDataProxy_columnCategoryIndex},
    {sipName_columnRole, meth_QItemModelSurfaceDataProxy_columnRole, METH_VARARGS, doc_QItemModelSurfaceDataProxy_columnRole},
    {sipName_columnRolePattern, meth_QItemModelSurfaceDataProxy_columnRolePattern, METH_VARARGS, doc_QItemModelSurfaceDataProxy_columnRolePattern},
    {sipName_columnRoleReplace, meth_QItemModelSurfaceDataProxy_columnRoleReplace, METH_VARARGS, doc_QItemModelSurfaceDataProxy_columnRoleReplace},
    {sipName_itemModel, meth_QItemModelSurfaceDataProxy_itemModel, METH_VARARGS, doc_QItemModelSurfaceDataProxy_itemModel},
    {sipName_multiMatchBehavior, meth_QItemModelSurfaceDataProxy_multiMatchBehavior, METH_VARARGS, doc_QItemModelSurfaceDataProxy_multiMatchBehavior},
    {sipName_remap, meth_QItemModelSurfaceDataProxy_remap, METH_VARARGS, doc_QItemModelSurfaceDataProxy_remap},
    {sipName_rowCategories, meth_QItemModelSurfaceDataProxy_rowCategories, METH_VARARGS, doc_QItemModelSurfaceDataProxy_rowCategories},
    {sipName_rowCategoryIndex, meth_QItemModelSurfaceDataProxy_rowCategoryIndex, METH_VARARGS, doc_QItemModelSurfaceDataProxy_rowCategoryIndex},
    {sipName_rowRole, meth_QItemModelSurfaceDataProxy_rowRole, METH_VARARGS, doc_QItemModelSurfaceDataProxy_rowRole},
    {sipName_rowRolePattern, meth_QItemModelSurfaceDataProxy_rowRolePattern, METH_VARARGS, doc_QItemModelSurfaceDataProxy_rowRolePattern},
    {sipName_rowRoleReplace, meth_QItemModelSurfaceDataProxy_rowRoleReplace, METH_VARARGS, doc_QItemModelSurfaceDataProxy_rowRoleReplace},
    {sipName_setAutoColumnCategories, meth_QItemModelSurfaceDataProxy_setAutoColumnCategories, METH_VARARGS, doc_QItemModelSurfaceDataProxy_setAutoColumnCategories},
    {sipName_setAutoRowCategories, meth_QItemModelSurfaceDataProxy_setAutoRowCategories, METH_VARARGS, doc_QItemModelSurfaceDataProxy_setAutoRowCategories},
    {sipName_setColumnCategories, meth_QItemModelSurfaceDataProxy_setColumnCategories, METH_VARARGS, doc_QItemModelSurfaceDataProxy_setColumnCategories},
    {sipName_setColumnRole, meth_QItemModelSurfaceDataProxy_setColumnRole, METH_VARARGS, doc_QItemModelSurfaceDataProxy_setColumnRole},
    {sipName_setColumnRolePattern, meth_QItemModelSurfaceDataProxy_setColumnRolePattern, METH_VARARGS, doc_QItemModelSurfaceDataProxy_setColumnRolePattern},
    {sipName_setColumnRoleReplace, meth_QItemModelSurfaceDataProxy_setColumnRoleReplace, METH_VARARGS, doc_QItemModelSurfaceDataProxy_setColumnRoleReplace},
    {sipName_setItemModel, meth_QItemModelSurfaceDataProxy_setItemModel, METH_VARARGS, doc_QItemModelSurfaceDataProxy_setItemModel},
    {sipName_setMultiMatchBehavior, meth_QItemModelSurfaceDataProxy_setMultiMatchBehavior, METH_VARARGS, doc_QItemModelSurfaceDataProxy_setMultiMatchBehavior},
    {sipName_setRowCategories, meth_QItemModelSurfaceDataProxy_setRowCategories, METH_VARARGS, doc_QItemModelSurfaceDataProxy_setRowCategories},
    {sipName_setRowRole, meth_QItemModelSurfaceDataProxy_setRowRole, METH_VARARGS, doc_QItemModelSurfaceDataProxy_setRowRole},
    {sipName_setRowRolePattern, meth_QItemModelSurfaceDataProxy_setRowRolePattern, METH_VARARGS, doc_QItemModelSurfaceDataProxy_setRowRolePattern},
    {sipName_setRowRoleReplace, meth_QItemModelSurfaceDataProxy_setRowRoleReplace, METH_VARARGS, doc_QItemModelSurfaceDataProxy_setRowRoleReplace},
    {sipName_setUseModelCategories, meth_QItemModelSurfaceDataProxy_setUseModelCategories, METH_VARARGS, doc_QItemModelSurfaceDataProxy_setUseModelCategories},
    {sipName_setXPosRole, meth_QItemModelSurfaceDataProxy_setXPosRole, METH_VARARGS, doc_QItemModelSurfaceDataProxy_setXPosRole},
    {sipName_setXPosRolePattern, meth_QItemModelSurfaceDataProxy_setXPosRolePattern, METH_VARARGS, doc_QItemModelSurfaceDataProxy_setXPosRolePattern},
    {sipName_setXPosRoleReplace, meth_QItemModelSurfaceDataProxy_setXPosRoleReplace, METH_VARARGS, doc_QItemModelSurfaceDataProxy_setXPosRoleReplace},
    {sipName_setYPosRole, meth_QItemModelSurfaceDataProxy_setYPosRole, METH_VARARGS, doc_QItemModelSurfaceDataProxy_setYPosRole},
    {sipName_setYPosRolePattern, meth_QItemModelSurfaceDataProxy_setYPosRolePattern, METH_VARARGS, doc_QItemModelSurfaceDataProxy_setYPosRolePattern},
    {sipName_setYPosRoleReplace, meth_QItemModelSurfaceDataProxy_setYPosRoleReplace, METH_VARARGS, doc_QItemModelSurfaceDataProxy_setYPosRoleReplace},
    {sipName_setZPosRole, meth_QItemModelSurfaceDataProxy_setZPosRole, METH_VARARGS, doc_QItemModelSurfaceDataProxy_setZPosRole},
    {sipName_setZPosRolePattern, meth_QItemModelSurfaceDataProxy_setZPosRolePattern, METH_VARARGS, doc_QItemModelSurfaceDataProxy_setZPosRolePattern},
    {sipName_setZPosRoleReplace, meth_QItemModelSurfaceDataProxy_setZPosRoleReplace, METH_VARARGS, doc_QItemModelSurfaceDataProxy_setZPosRoleReplace},
    {sipName_useModelCategories, meth_QItemModelSurfaceDataProxy_useModelCategories, METH_VARARGS, doc_QItemModelSurfaceDataProxy_useModelCategories},
    {sipName_xPosRole, meth_QItemModelSurfaceDataProxy_xPosRole, METH_VARARGS, doc_QItemModelSurfaceDataProxy_xPosRole},
    {sipName_xPosRolePattern, meth_QItemModelSurfaceDataProxy_xPosRolePattern, METH_VARARGS, doc_QItemModelSurfaceDataProxy_xPosRolePattern},
    {sipName_xPosRoleReplace, meth_QItemModelSurfaceDataProxy_xPosRoleReplace, METH_VARARGS, doc_QItemModelSurfaceDataProxy_xPosRoleReplace},
    {sipName_yPosRole, meth_QItemModelSurfaceDataProxy_yPosRole, METH_VARARGS, doc_QItemModelSurfaceDataProxy_yPosRole},
    {sipName_yPosRolePattern, meth_QItemModelSurfaceDataProxy_yPosRolePattern, METH_VARARGS, doc_QItemModelSurfaceDataProxy_yPosRolePattern},
    {sipName_yPosRoleReplace, meth_QItemModelSurfaceDataProxy_yPosRoleReplace, METH_VARARGS, doc_QItemModelSurfaceDataProxy_yPosRoleReplace},
    {sipName_zPosRole, meth_QItemModelSurfaceDataProxy_zPosRole, METH_VARARGS, doc_QItemModelSurfaceDataProxy_zPosRole},
    {sipName_zPosRolePattern, meth_QItemModelSurfaceDataProxy_zPosRolePattern, METH_VARARGS, doc_QItemModelSurfaceDataProxy_zPosRolePattern},
    {sipName_zPosRoleReplace, meth_QItemModelSurfaceDataProxy_zPosRoleReplace, METH_VARARGS, doc_QItemModelSurfaceDataProxy_zPosRoleReplace}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QItemModelSurfaceDataProxy[] = {
    {sipName_MMBFirst, static_cast<int>(::QItemModelSurfaceDataProxy::MMBFirst)},
    {sipName_MMBLast, static_cast<int>(::QItemModelSurfaceDataProxy::MMBLast)},
    {sipName_MMBAverage, static_cast<int>(::QItemModelSurfaceDataProxy::MMBAverage)},
    {sipName_MMBCumulativeY, static_cast<int>(::QItemModelSurfaceDataProxy::MMBCumulativeY)},
    {0, 0}
};

PyDoc_STRVAR(doc_QItemModelSurfaceDataProxy, "\1QItemModelSurfaceDataProxy(itemModel: QAbstractItemModel|None, parent: QObject|None = None)\n"
"QItemModelSurfaceDataProxy(itemModel: QAbstractItemModel|None, yPosRole: str|None, parent: QObject|None = None)\n"
"QItemModelSurfaceDataProxy(itemModel: QAbstractItemModel|None, rowRole: str|None, columnRole: str|None, yPosRole: str|None, parent: QObject|None = None)\n"
"QItemModelSurfaceDataProxy(itemModel: QAbstractItemModel|None, rowRole: str|None, columnRole: str|None, yPosRole: str|None, rowCategories: Iterable[str|None], columnCategories: Iterable[str|None], parent: QObject|None = None)\n"
"QItemModelSurfaceDataProxy(itemModel: QAbstractItemModel|None, rowRole: str|None, columnRole: str|None, xPosRole: str|None, yPosRole: str|None, zPosRole: str|None, parent: QObject|None = None)\n"
"QItemModelSurfaceDataProxy(itemModel: QAbstractItemModel|None, rowRole: str|None, columnRole: str|None, xPosRole: str|None, yPosRole: str|None, zPosRole: str|None, rowCategories: Iterable[str|None], columnCategories: Iterable[str|None], parent: QObject|None = None)\n"
"QItemModelSurfaceDataProxy(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QItemModelSurfaceDataProxy[] = {
    {"multiMatchBehaviorChanged(QItemModelSurfaceDataProxy::MultiMatchBehavior)", "\1multiMatchBehaviorChanged(self, behavior: QItemModelSurfaceDataProxy.MultiMatchBehavior)", SIP_NULLPTR, SIP_NULLPTR},
    {"zPosRoleReplaceChanged(QString)", "\1zPosRoleReplaceChanged(self, replace: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"yPosRoleReplaceChanged(QString)", "\1yPosRoleReplaceChanged(self, replace: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"xPosRoleReplaceChanged(QString)", "\1xPosRoleReplaceChanged(self, replace: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"columnRoleReplaceChanged(QString)", "\1columnRoleReplaceChanged(self, replace: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"rowRoleReplaceChanged(QString)", "\1rowRoleReplaceChanged(self, replace: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"zPosRolePatternChanged(QRegularExpression)", "\1zPosRolePatternChanged(self, pattern: QRegularExpression)", SIP_NULLPTR, SIP_NULLPTR},
    {"yPosRolePatternChanged(QRegularExpression)", "\1yPosRolePatternChanged(self, pattern: QRegularExpression)", SIP_NULLPTR, SIP_NULLPTR},
    {"xPosRolePatternChanged(QRegularExpression)", "\1xPosRolePatternChanged(self, pattern: QRegularExpression)", SIP_NULLPTR, SIP_NULLPTR},
    {"columnRolePatternChanged(QRegularExpression)", "\1columnRolePatternChanged(self, pattern: QRegularExpression)", SIP_NULLPTR, SIP_NULLPTR},
    {"rowRolePatternChanged(QRegularExpression)", "\1rowRolePatternChanged(self, pattern: QRegularExpression)", SIP_NULLPTR, SIP_NULLPTR},
    {"autoColumnCategoriesChanged(bool)", "\1autoColumnCategoriesChanged(self, enable: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"autoRowCategoriesChanged(bool)", "\1autoRowCategoriesChanged(self, enable: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"useModelCategoriesChanged(bool)", "\1useModelCategoriesChanged(self, enable: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"columnCategoriesChanged()", "\1columnCategoriesChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"rowCategoriesChanged()", "\1rowCategoriesChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"zPosRoleChanged(QString)", "\1zPosRoleChanged(self, role: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"yPosRoleChanged(QString)", "\1yPosRoleChanged(self, role: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"xPosRoleChanged(QString)", "\1xPosRoleChanged(self, role: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"columnRoleChanged(QString)", "\1columnRoleChanged(self, role: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"rowRoleChanged(QString)", "\1rowRoleChanged(self, role: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"itemModelChanged(const QAbstractItemModel*)", "\1itemModelChanged(self, itemModel: QAbstractItemModel|None)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QItemModelSurfaceDataProxy = {
    &::QItemModelSurfaceDataProxy::staticMetaObject,
    signals_QItemModelSurfaceDataProxy,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDataVisualization_QItemModelSurfaceDataProxy = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QItemModelSurfaceDataProxy,
        SIP_NULLPTR,
        &plugin_QItemModelSurfaceDataProxy,
    },
    {
        sipNameNr_QItemModelSurfaceDataProxy,
        {0, 0, 1},
        47, methods_QItemModelSurfaceDataProxy,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QItemModelSurfaceDataProxy, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QItemModelSurfaceDataProxy,
    -1,
    -1,
    supers_QItemModelSurfaceDataProxy,
    SIP_NULLPTR,
    init_type_QItemModelSurfaceDataProxy,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QItemModelSurfaceDataProxy,
    SIP_NULLPTR,
    array_QItemModelSurfaceDataProxy,
    SIP_NULLPTR,
    release_QItemModelSurfaceDataProxy,
    cast_QItemModelSurfaceDataProxy,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QItemModelSurfaceDataProxy,
    sizeof (::QItemModelSurfaceDataProxy),
};
